# TartaAPI-Python

## Overview
TartaAPI-Python is a Python wrapper for the Tarta API, designed to seamlessly integrate AI-powered job search functionality into your applications.

## API Documentation
For detailed API documentation, visit:  
[Tarta API Documentation](https://api.tarta.ai/swagger/index.html)

## What is Tarta?
Tarta.ai is a sophisticated AI platform that consolidates job listings from a wide range of sources, including job boards and social media. The platform streamlines the job search experience, matching users with suitable vacancies and even facilitating interview scheduling.

To learn more, visit:  
[Tarta Official Website](https://tarta.ai/)

## ChatGPT Integration
Tarta is also available as a ChatGPT plugin to enhance your job search experience:  
[Tarta ChatGPT Plugin](https://chat.openai.com/g/g-Gkf9YM4sR-job-search-in-the-us)

## Installation
To install TartaAPI-Python via pip, use the following command:
```sh
pip install tarta-api
```

## Usage Example
Here's a simple example demonstrating how to use the library to execute a job search:

```python
from tarta_api.job_search import JobSearchService, JobSearchRequest

def search_jobs(title: str, size: int = 5):
    request = JobSearchRequest(title=title, size=size)
    
    try:
        results = JobSearchService.search_jobs(request)
        jobs = results.get("jobs", [])
        
        if not jobs:
            print("No job results found.")
            return
        
        print("Job Search Results:")
        for job in jobs:
            job_name = job.get("name", "N/A")
            company = job.get("companyName", "N/A")
            location = job.get("location", {})
            city = location.get("city", "Unknown")
            state = location.get("state", "Unknown")
            country = location.get("country", "Unknown")
            source = job.get("feed", "N/A")
            posted_date = job.get("created", "N/A")
            
            print(f"Job: {job_name} at {company}")
            print(f"Location: {city}, {state}, {country}")
            print(f"Source: {source}")
            print(f"Posted: {posted_date}\n")
    
    except Exception as e:
        print(f"Error fetching job results: {e}")

search_jobs("python", size=2)

```

## Key Features
- **Effortless API Integration**: Interact with Tarta's API using straightforward Python methods.
- **AI Matching**: Utilize AI algorithms to find jobs that align with user profiles and preferences.
- **Interview Scheduling**: Automate interview scheduling to streamline the application process.

## Contributions
Contributions are welcome! Feel free to open issues or submit pull requests to enhance the library.

## License
This project is under the MIT License.

---
Experience the efficiency of Tarta and integrate AI-powered job search into your Python applications today!